disconnect: Close all connections and remove them from the connections...

View source: R/disconnect.R

disconnectR Documentation

Close all connections and remove them from the connections cache

Description

Close all connections and remove them from the connections cache

Usage

disconnect()

Value

NULL, invisibly

Examples


library(sqlhelper)
connect(
  system.file("examples",
              "sqlhelper_db_conf.yml",
              package="sqlhelper")
)
disconnect()


sqlhelper documentation built on March 26, 2026, 5:09 p.m.